#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utilt_1 = require("./utilt");
const fs = require("fs");
const path = require("path");
let argumentList = process.argv;
let currentDir = process.cwd();
let rootPath = path.join(__dirname, "..");
let argObj = convertArgJson();
let buildpath = "build";
let staticPath = "public";
let projectName = "";
if (argObj && argObj.project) {
    projectName = argObj.project;
    let projectJson = JSON.parse(fs.readFileSync(process.cwd() + "/project.json", "utf-8"));
    let projectData = projectJson[argObj.project];
    buildpath = (projectData === null || projectData === void 0 ? void 0 : projectData.build_path) || "build";
    staticPath = (projectData === null || projectData === void 0 ? void 0 : projectData.static_path) || "public";
}
if (argumentList.length > 2) {
    if (argumentList[2] == "serve") {
        try {
            let cmd = `npx webpack serve --config ${rootPath}/webpack.config.js`;
            if (projectName) {
                cmd = cmd + " --env project=" + projectName;
            }
            (0, utilt_1.executeCmd)(cmd)
                .then((result) => {
                console.log(result);
            })
                .catch((err) => {
                console.log("err", err);
            });
        }
        catch (err) {
            console.log(err);
        }
    }
    else if (argumentList[2] == "build") {
        let cmd = `npx webpack --config ${rootPath}/webpack-build.config.js`;
        if (projectName) {
            cmd = cmd + " --env project=" + projectName;
        }
        if (!fs.existsSync(currentDir + "/" + buildpath)) {
            fs.mkdirSync(currentDir + "/" + buildpath);
        }
        fs.cpSync(currentDir + "/" + staticPath, currentDir + "/" + buildpath, { recursive: true });
        (0, utilt_1.executeCmd)(cmd)
            .then((result) => {
            console.log(result);
        })
            .catch((err) => {
            console.log("err", err);
        });
    }
    else if (argumentList[2] == "create") {
        fs.cpSync(rootPath + "/example", currentDir, { recursive: true });
    }
}
function convertArgJson() {
    let argList = process.argv;
    let obj = {};
    argList.forEach((d, i) => {
        if (d.search("--") >= 0) {
            let key = d.replace("--", "");
            obj[key] = argList[i + 1];
        }
    });
    return obj;
}
//# sourceMappingURL=main.js.map